@@ -1,7 +1,7 @@
 /*
  * kism3d.c
  *
- * Copyright (C) 2006  Marek Lindner <lindner_marek@yahoo.de>
+ * Copyright (C) 2006-2011  Marek Lindner <lindner_marek@yahoo.de>
  *
  * This file is part of kism3d, an 802.11 visualizer for s3d.
  * See http://s3d.berlios.de/ for more updates.
@@ -595,6 +595,6 @@ int main(int argc, char *argv[])
 
 	}
 
-	return (0);
+	return 0;
 
 }
