@@ -1,6 +1,6 @@
 /*
  * fs.c
- * Copyright (C) 2004-2008 Simon Wunderlich <dotslash@packetmixer.de>
+ * Copyright (C) 2004-2011  Simon Wunderlich <dotslash@packetmixer.de>
  *
  * This file is part of s3dfm, a s3d file manager.
  * See http://s3d.berlios.de/ for more updates.
@@ -61,7 +61,7 @@ filelist *fl_new(char *path)
 		j = 0;
 		fl->n = n - 2 ; /* ignore . and .. */
 		fl->p = (struct _t_file*)malloc(sizeof(t_file) * fl->n);
-		for (i = 0;i < n;i++) {
+		for (i = 0; i < n; i++) {
 			name = namelist[i]->d_name;
 			if (!((strcmp(name, ".") == 0) || (strcmp(name, "..") == 0))) { /* ignore */
 				fl->p[j].name = (char*)malloc(strlen(name) + strlen(path) + 2);
@@ -82,13 +82,13 @@ filelist *fl_new(char *path)
 		}
 		free(namelist);
 	}
-	return(fl);
+	return fl;
 }
 /* delete the filelist */
 void fl_del(filelist *fl)
 {
 	int i;
-	for (i = 0;i < fl->n;i++) {
+	for (i = 0; i < fl->n; i++) {
 		free(fl->p[i].name);
 		if (fl->p[i].anode != NULL) {
 			/* maybe let node_delete do that? */
@@ -155,7 +155,7 @@ void fs_fl_approx(filelist *fl, int *files, int *dirs, int *bytes)
 	*dirs = 0;
 	*bytes = 0;
 
-	for (i = 0;i < fl->n;i++) {
+	for (i = 0; i < fl->n; i++) {
 		fs_approx(fl->p[i].name, &sfiles, &sdirs, &sbytes);
 		*files +=  sfiles;
 		*dirs +=   sdirs;
@@ -171,7 +171,7 @@ int fs_copy(char *source, char *dest)
 	char buf[1024];
 	int n;
 	if (-1 == stat(source, &s))
-		return(0);
+		return 0;
 	switch (s.st_mode&S_IFMT) {
 	case S_IFDIR:
 		fl = fl_new(source);
@@ -193,14 +193,14 @@ int fs_copy(char *source, char *dest)
 		printf("open source...");
 		if (NULL == (fps = fopen(source, "rb"))) {
 			fs_error("fs_copy():fopen(source)", source);
-			return(-1);
+			return -1;
 		}
 		printf("ok\n");
 		printf("open dest...");
 		if (NULL == (fpd = fopen(dest, "wb"))) {
 			fs_error("fs_copy():fopen(source)", source);
 			fclose(fps);
-			return(-1);
+			return -1;
 		}
 		printf("ok\n");
 		/* TODO: overwrite protection etc */
@@ -219,7 +219,7 @@ int fs_copy(char *source, char *dest)
 		fclose(fpd);
 
 	}
-	return(0);
+	return 0;
 }
 /* copy the source to the destination, destination should be a directory. */
 int fs_fl_copy(filelist *fl, const char *dest)
@@ -229,7 +229,7 @@ int fs_fl_copy(filelist *fl, const char *dest)
 	char *sdest;
 	char *bname;
 	r = 0;
-	for (i = 0;i < fl->n;i++) {
+	for (i = 0; i < fl->n; i++) {
 		fl->p[i].state = STATE_INUSE;
 		bname = basename(fl->p[i].name);
 		sdest = (char*)malloc(strlen(dest) + strlen(bname) + 2);
@@ -243,7 +243,7 @@ int fs_fl_copy(filelist *fl, const char *dest)
 		fl->p[i].state = STATE_FINISHED;
 	}
 
-	return(r);
+	return r;
 }
 /* recursively unlink a dir or file. */
 int fs_unlink(char *dest)
@@ -251,41 +251,41 @@ int fs_unlink(char *dest)
 	filelist *fl;
 	struct stat s;
 
-	if (-1 == stat(dest, &s))  return(-1);
+	if (-1 == stat(dest, &s))  return -1;
 	if ((s.st_mode&S_IFMT) == S_IFDIR) {
 		printf("%s is a dir, removing below ...\n", dest);
 		fl = fl_new(dest);
 		if (fs_fl_unlink(fl)) {
 			fl_del(fl);
-			return(-1);
+			return -1;
 		} else {
 			fl_del(fl);
 			printf("removing %s\n", dest);
 			if (rmdir(dest) == -1) {
 				fs_error("fs_fl_unlink(): rmdir()", dest);
-				return(-1);
+				return -1;
 			}
 		}
 	} else {
 		if (unlink(dest) == -1) {
 			fs_error("fs_fl_unlink(): unlink()", dest);
-			return(-1);
+			return -1;
 		}
 	}
-	return(0);
+	return 0;
 }
 /* remove a lot of files */
 int fs_fl_unlink(filelist *fl)
 {
 	int i, r;
 	r = 0;
-	for (i = 0;i < fl->n;i++) {
+	for (i = 0; i < fl->n; i++) {
 		fl->p[i].state = STATE_INUSE;
 		printf("-> atomic unlink %s\n", fl->p[i].name);
 		r |= fs_unlink(fl->p[i].name);
 		fl->p[i].state = STATE_FINISHED;
 	}
-	return(r);
+	return r;
 
 }
 int fs_move(char *source, char *dest)
@@ -298,11 +298,11 @@ int fs_move(char *source, char *dest)
 			break;
 		default:
 			fs_error("fs_move()", dest);
-			return(-1); /* can't help it */
+			return -1; /* can't help it */
 
 		}
 	}
-	return(0);
+	return 0;
 }
 
 /* moves the source to the destination */
@@ -313,7 +313,7 @@ int fs_fl_move(filelist *fl, const char *dest)
 	char *sdest;
 	char *bname;
 	r = 0;
-	for (i = 0;i < fl->n;i++) {
+	for (i = 0; i < fl->n; i++) {
 		fl->p[i].state = STATE_INUSE;
 		bname = basename(fl->p[i].name);
 		sdest = (char*)malloc(strlen(dest) + strlen(bname) + 2);
@@ -327,7 +327,7 @@ int fs_fl_move(filelist *fl, const char *dest)
 		fl->p[i].state = STATE_FINISHED;
 	}
 
-	return(r);
+	return r;
 }
 
 /* write an error and wait for a reaction */
@@ -343,5 +343,5 @@ int fs_error(const char *message, char *file)
 	printf("[FS ERROR]: %s %s %s", message, file, strerror(errno));
 	while (fs_err.state != ESTATE_NONE)
 		nanosleep(&t, NULL); /* until situation clear, wait (and don't waste cpu-time) */
-	return(0);
+	return 0;
 }
