@@ -1,7 +1,7 @@
 /*
  * main.c
  *
- * Copyright (C) 2004-2008 Simon Wunderlich <dotslash@packetmixer.de>
+ * Copyright (C) 2004-2011  Simon Wunderlich <dotslash@packetmixer.de>
  *
  * This file is part of s3dfm, a s3d file manager.
  * See http://s3d.berlios.de/ for more updates.
@@ -40,19 +40,19 @@ int parse_dir(t_node *dir)
 
 	printf("parse_dir( %s )\n", dir->name);
 	node_path(dir, path);
-	for (i = 0;i < dir->n_sub;i++) {
+	for (i = 0; i < dir->n_sub; i++) {
 		dir->sub[i]->check = 1;
 	}
 	n = scandir(path, &namelist, NULL, alphasort);
 	if (n < 0) {
 		window_fs_errno(path);
-		return(-1);
+		return -1;
 	} else {
 		oldn = dir->n_sub;
 		while (n--) {
 			nstr = namelist[n]->d_name;
 			/* setup kids in the sub */
-			for (i = 0;i < oldn;i++) /* see if it's already there */
+			for (i = 0; i < oldn; i++) /* see if it's already there */
 				if (dir->sub[i])
 					if (0 == strcmp(namelist[n]->d_name, dir->sub[i]->name))
 						break;
@@ -73,7 +73,7 @@ int parse_dir(t_node *dir)
 				dir->sub[i]->pindex = i;
 				strncpy(ndir, path, M_DIR);
 				mstrncat(ndir, "/", M_DIR);
-				strncat(ndir, namelist[n]->d_name, M_DIR);
+				mstrncat(ndir, namelist[n]->d_name, M_DIR);
 				if (fs_isdir(ndir))
 					dir->sub[i]->type = T_FOLDER;
 				dir->sub[i]->check = 0; /* check=0 means we've already processed this item */
@@ -82,7 +82,7 @@ int parse_dir(t_node *dir)
 		}
 		free(namelist);
 		dir->check = 0;
-		for (i = 0;i < dir->n_sub;i++)
+		for (i = 0; i < dir->n_sub; i++)
 			if (dir->sub[i]->check) {
 				/* not checked yet... that means the item is not in the reparsed directory, ie vanished.
 				 * so we're removing it from our queue */
@@ -96,6 +96,6 @@ int parse_dir(t_node *dir)
 		if (dir->check)  dir->sub = (struct _t_node**)realloc(dir->sub , dir->n_sub * sizeof(t_node *));
 		dir->parsed = 1;
 	}
-	return(0);
+	return 0;
 }
 
