@@ -1,7 +1,7 @@
 /*
  * s3dfm.h
  *
- * Copyright (C) 2004-2008 Simon Wunderlich <dotslash@packetmixer.de>
+ * Copyright (C) 2004-2011  Simon Wunderlich <dotslash@packetmixer.de>
  *
  * This file is part of s3dfm, a s3d file manager.
  * See http://s3d.berlios.de/ for more updates.
@@ -21,6 +21,8 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
+#ifndef _S3DFM_H_
+#define _S3DFM_H_
 
 #include <s3d.h>
 #include <s3dw.h>
@@ -209,3 +211,5 @@ char  *mstrncpy(char *dest, const char *src, int n);
 /* fly.c */
 int    fly_set_absolute_position(t_node *node);
 t_node   *fly_create_anode(t_node *node);
+
+#endif /* _S3DFM_H_ */
