@@ -1,7 +1,7 @@
 /*
  * gps.c
  *
- * Copyright (C) 2006-2008 Simon Wunderlich <dotslash@packetmixer.de>
+ * Copyright (C) 2006-2011  Simon Wunderlich <dotslash@packetmixer.de>
  *
  * This file is part of s3dosm, a gps card application for s3d.
  * See http://s3d.berlios.de/ for more updates.
@@ -46,22 +46,17 @@ static float      lat, lon, tlat, tlon; /* we have the same in nav.c, this one i
 static float     lat_old, lon_old;
 static float     speed_old = 0.0;
 void      show_gpsdata(struct gps_data_t *dgps);
-void     show_position(struct gps_data_t *dgps);
+static void     show_position(struct gps_data_t *dgps);
 
 void show_gpsdata(struct gps_data_t *dgps)
 {
 	if (!dgps->online)
 		printf("WARNING: no connection to gps device\n");
-#ifdef HAVE_GPS_NEW
+
 	printf("[%d] lat/long: [%f|%f], altitude %f\n", frame, dgps->fix.latitude, dgps->fix.longitude, dgps->fix.altitude);
 	printf("speed [kph]: %f\n", dgps->fix.speed / KNOTS_TO_KPH);
-	printf("used %d/%d satellits\n", dgps->satellites_used, dgps->satellites);
-#else
-	printf("[%d] lat/long: [%f|%f], altitude %f\n", frame, dgps->latitude, dgps->longitude, dgps->altitude);
-	printf("speed [kph]: %f\n", dgps->speed / KNOTS_TO_KPH);
-	printf("used %d/%d satellits\n", dgps->satellites_used, dgps->satellites);
+	printf("used %d/%d satellits\n", dgps->satellites_used, dgps->satellites_visible);
 
-#endif
 	switch (dgps->status) {
 	case STATUS_NO_FIX:
 		printf("status: no fix\n");
@@ -73,12 +68,8 @@ void show_gpsdata(struct gps_data_t *dgps)
 		printf("status: dgps fix\n");
 		break;
 	}
-#ifdef HAVE_GPS_NEW
-	switch (dgps->fix.mode)
-#else
-	switch (dgps->mode)
-#endif
-	{
+
+	switch (dgps->fix.mode) {
 	case MODE_NOT_SEEN:
 		printf("mode: not seen yet\n");
 		break;
@@ -94,12 +85,12 @@ void show_gpsdata(struct gps_data_t *dgps)
 	}
 }
 #define BUFSIZE  1024
-void show_position(struct gps_data_t *dgps)
+static void show_position(struct gps_data_t *dgps)
 {
 	int fix = 1;
 	float la, lo, heading, speed, slen;
 	char buf[BUFSIZE+1];
-#ifdef HAVE_GPS_NEW
+
 	if (!dgps->online)
 		fix = 0;
 	switch (dgps->fix.mode) {
@@ -116,22 +107,6 @@ void show_position(struct gps_data_t *dgps)
 	heading = -dgps->fix.track;
 	speed = dgps->fix.speed;
 
-#else
-	if (!dgps->online)
-		fix = 0;
-	switch (dgps->mode) {
-	case MODE_NOT_SEEN:
-		fix = 0;
-		break;
-	case MODE_NO_FIX:
-		fix = 0;
-		break;
-	}
-	la = dgps->latitude;
-	lo = dgps->longitude;
-	heading = -dgps->track;
-	speed = dgps->speed * KNOTS_TO_MPH / METERS_TO_MILES / 3600; /* speed in knots -> miles per hour -> meter per hour -> meter per secon */
-#endif
 	tlat = la;
 	tlon = lo;
 	if (fix) {
@@ -199,7 +174,7 @@ int gps_init(const char *gpshost)
 		}
 		/*  printf("no connection to gpsd\n");*/
 		fprintf(stderr, "s3dosm: no gpsd running or network error: %d, %s\n" ,  errno, err_str);
-		return(-1);
+		return -1;
 	}
 	sock_opts = fcntl(dgps->gps_fd, F_GETFL, 0);
 	fcntl(dgps->gps_fd, F_SETFL, sock_opts | O_NONBLOCK);
@@ -213,8 +188,8 @@ int gps_init(const char *gpshost)
 	tlat = lat = lat_old = 0.0;
 	tlon = lon = lon_old = 0.0;
 	gps_active = 1;
-	gps_query(dgps, "w+x\n");
-	return(0);
+	gps_stream(dgps, WATCH_ENABLE, NULL);
+	return 0;
 }
 int gps_main(void)
 {
@@ -244,7 +219,7 @@ int gps_main(void)
 	}
 	draw_translate_icon(user_icon_rotator, lat, lon);
 	frame++;
-	return(0);
+	return 0;
 }
 int gps_quit(void)
 {
@@ -253,21 +228,21 @@ int gps_quit(void)
 		gps_active = 0;
 		gps_close(dgps);
 	}
-	return(0);
+	return 0;
 }
 #else
 
 int gps_init(const char *S3DOSMUNUSED(gpshost))
 {
 	printf("GPS support not compiled in!\n");
-	return(0);
+	return 0;
 }
 int gps_main(void)
 {
-	return(0);
+	return 0;
 }
 int gps_quit(void)
 {
-	return(0);
+	return 0;
 }
 #endif
