@@ -1,7 +1,7 @@
 /*
  * io.c
  *
- * Copyright (C) 2006-2008 Simon Wunderlich <dotslash@packetmixer.de>
+ * Copyright (C) 2006-2011  Simon Wunderlich <dotslash@packetmixer.de>
  *
  * This file is part of s3dosm, a gps card application for s3d.
  * See http://s3d.berlios.de/ for more updates.
@@ -40,21 +40,21 @@ char *read_file(const char *fname, int *fsize)
 
 	if ((fp = fopen(fname, "rb")) == NULL) {
 		fprintf(stderr, "read_file( %s ):fopen(): %s", fname, strerror(errno));
-		return(NULL);
+		return NULL;
 	}
 	if (fstat(fileno(fp), &bf))    {
 		fprintf(stderr, "read_file( %s ):fopen(): %s", fname, strerror(errno));
-		return(NULL);
+		return NULL;
 	}
 	filesize = bf.st_size;
 	if ((buf = (char*)malloc(filesize)) == NULL)  {
 		fprintf(stderr, "read_file( %s ):malloc(): %s", fname, strerror(errno));
-		return(NULL);
+		return NULL;
 	}
 	fread(buf, filesize, 1, fp);
 	fclose(fp);
 	if (fsize != NULL) *fsize = filesize;
-	return(buf);
+	return buf;
 }
 
 int process_args(int argc, char **argv)
@@ -64,7 +64,8 @@ int process_args(int argc, char **argv)
 	float    minlat, minlon, maxlat, maxlon;
 	char     info[1024];
 	struct option long_options[] = {
-		{"help", 0, NULL, 'h'
+		{
+			"help", 0, NULL, 'h'
 		}, {"osm", 1, NULL, 'o'}, {NULL, 0, NULL, 0}
 	};
 	optind = 0;
@@ -78,7 +79,7 @@ int process_args(int argc, char **argv)
 				layerset_add(load_osm_web(minlat, minlon, maxlat, maxlon));
 			else {
 				printf("%s: bad map bounding box", optarg);
-				return(-1);
+				return -1;
 			}
 			break;
 		case 'h':
@@ -92,12 +93,12 @@ int process_args(int argc, char **argv)
 			printf("\t+ Kismet .xml Logs\n");
 			printf("\t+ Opemstreetmap .osm files\n\n");
 			s3d_usage(); /* add s3d usage */
-			return(-1);
+			return -1;
 		default:
 			break;
 		}
 	}
-	for (i = 1;i < argc;i++) {
+	for (i = 1; i < argc; i++) {
 		if (strstr(argv[i], ".osm") - argv[i] == (signed)(strlen(argv[i]) - 4)) {
 			snprintf(info, 1024, "loading OSM-File: %s", argv[i]);
 			load_window(info);
@@ -120,6 +121,6 @@ int process_args(int argc, char **argv)
 		}
 	}
 	load_window_remove();
-	return(0);
+	return 0;
 }
 
