@@ -1,8 +1,8 @@
 /*
  * osm.c
  *
- * Copyright (C) 2006-2008 Simon Wunderlich <dotslash@packetmixer.de>,
- *                         Sven Eckelmann <sven.eckelmann@gmx.de>
+ * Copyright (C) 2006-2011  Simon Wunderlich <dotslash@packetmixer.de>
+ * Copyright (C) 2008-2011  Sven Eckelmann <sven@narfation.org>
  *
  * This file is part of s3dosm, a gps card application for s3d.
  * See http://s3d.berlios.de/ for more updates.
@@ -35,9 +35,9 @@ static int parse_osm_tags(object_t *obj, xmlNodePtr cur)
 	xmlAttrPtr attr;
 	char *v, *k;
 	v = k = NULL;
-	for (c = cur->children;c != NULL; c = c->next) {
+	for (c = cur->children; c != NULL; c = c->next) {
 		if (0 == strcmp((char *)c->name, "tag")) {
-			for (attr = c->properties;attr;attr = attr->next) {
+			for (attr = c->properties; attr; attr = attr->next) {
 				if (0 == strcmp((char *)attr->name, "k"))     k = (char *)attr->children->content;
 				else if (0 == strcmp((char *)attr->name, "v"))   v = (char *)attr->children->content;
 			}
@@ -45,7 +45,7 @@ static int parse_osm_tags(object_t *obj, xmlNodePtr cur)
 				db_add_tag(obj, k, v);
 		}
 	}
-	return(0);
+	return 0;
 
 }
 static void parse_osm_way(xmlNodePtr cur)
@@ -60,13 +60,13 @@ static void parse_osm_way(xmlNodePtr cur)
 	way_init(&way);
 
 	way.base.layerid = layerid;
-	for (attr = cur->properties;attr;attr = attr->next)
+	for (attr = cur->properties; attr; attr = attr->next)
 		if (0 == strcmp((char *)attr->name, "id"))    way.base.id = strtol((char *)attr->children->content, NULL, 10);
 	db_insert_way_only(&way);
 	parse_osm_tags(OBJECT_T(&way), cur);
-	for (kids = cur->children;kids != NULL;kids = kids->next) {
+	for (kids = cur->children; kids != NULL; kids = kids->next) {
 		if (0 == strcmp((char *)kids->name, "nd")) {
-			for (kattr = kids->properties;kattr;kattr = kattr->next)
+			for (kattr = kids->properties; kattr; kattr = kattr->next)
 				if (0 == strcmp((char *)kattr->name, "ref"))    nd = strtol((char *)kattr->children->content, NULL, 10);
 
 			if (last_nd != 0 && nd != 0) {
@@ -96,7 +96,7 @@ static void parse_osm_node(xmlNodePtr cur)
 	node_init(&node);
 
 	node.base.layerid = layerid;
-	for (attr = cur->properties;attr;attr = attr->next) {
+	for (attr = cur->properties; attr; attr = attr->next) {
 		if (0 == strcmp((char *)attr->name, "id"))    node.base.id =  strtol((char *)attr->children->content, NULL, 10);
 		else if (0 == strcmp((char *)attr->name, "lat"))   node.lat =   strtod((char *)attr->children->content, NULL);
 		else if (0 == strcmp((char *)attr->name, "lon"))   node.lon =   strtod((char *)attr->children->content, NULL);
@@ -121,17 +121,17 @@ layer_t *parse_osm(const char *buf, int length)
 	doc = xmlReadMemory(buf, length, "noname.xml", NULL, 0);
 	if (doc == NULL) {
 		fprintf(stderr, "Document not parsed successfully.\n");
-		return(NULL);
+		return NULL;
 	}
 	cur = xmlDocGetRootElement(doc);
 	if (cur == NULL) {
 		fprintf(stderr, "empty document\n");
 		xmlFreeDoc(doc);
-		return(NULL);
+		return NULL;
 	}
 	layerid = db_insert_layer("osm");
 	for (c = cur->children;  c != NULL;   c = c->next)   n++; /* count */
-	for (cur = cur->children;cur != NULL; cur = cur->next) {
+	for (cur = cur->children; cur != NULL; cur = cur->next) {
 		if (cur->type == XML_ELEMENT_NODE) {
 			if (0 == strcmp((char *)cur->name, "node"))    parse_osm_node(cur);
 			else if (0 == strcmp((char *)cur->name, "way"))   parse_osm_way(cur);
@@ -141,7 +141,7 @@ layer_t *parse_osm(const char *buf, int length)
 	xmlFreeDoc(doc);
 	db_flush();
 
-	return(layer);
+	return layer;
 }
 layer_t *load_osm_web(float minlon, float minlat, float maxlon, float maxlat)
 {
@@ -155,7 +155,7 @@ layer_t *load_osm_web(float minlon, float minlat, float maxlon, float maxlat)
 	ret = http_fetch(url, &fileBuf); /* Downloads page */
 	if (ret == -1) {
 		http_perror("http_fetch");
-		return(NULL);
+		return NULL;
 	}
 	layer = parse_osm(fileBuf, ret);
 	/* TODO: cleanup http-lib */
@@ -167,7 +167,7 @@ layer_t *load_osm_file(const char *filename)
 	int length;
 	char *file;
 	layer_t *ret;
-	if (NULL == (file = read_file(filename, &length))) return(NULL);
+	if (NULL == (file = read_file(filename, &length))) return NULL;
 	ret = parse_osm(file, length);
 	free(file);
 	return ret;
