@@ -1,7 +1,7 @@
 /*
  * filebrowser.c
  *
- * Copyright (C) 2004-2006 Simon Wunderlich <dotslash@packetmixer.de>
+ * Copyright (C) 2004-2011  Simon Wunderlich <dotslash@packetmixer.de>
  *
  * This file is part of s3d, a 3d network display server.
  * See http://s3d.berlios.de/ for more updates.
@@ -71,7 +71,7 @@ static int display_dir(const char *dir, int S3DUNUSED(depth), int  posx, int pos
 	struct stat s;
 	if (n_item) {
 		printf("freeing %d old items\n", n_item);
-		for (i = 0;i < n_item;i++) {
+		for (i = 0; i < n_item; i++) {
 			printf("deleting %d and %d\n", item[i].icon_oid, item[i].descr_oid);
 			s3d_del_object(item[i].descr_oid);
 			s3d_del_object(item[i].icon_oid);
@@ -83,7 +83,7 @@ static int display_dir(const char *dir, int S3DUNUSED(depth), int  posx, int pos
 	n = i = scandir(dir, &namelist, NULL, alphasort);
 	if (n < 0) {
 		perror("scandir");
-		return(-1);
+		return -1;
 	} else {
 		item = (struct t_item*)malloc(sizeof(struct t_item) * i);
 		n_item = i;
@@ -105,9 +105,7 @@ static int display_dir(const char *dir, int S3DUNUSED(depth), int  posx, int pos
 				stat(ndir, &s);
 				if (S_ISDIR(s.st_mode)) {
 					item[n].type = T_FOLDER;
-				}
-				else
-				{
+				} else {
 					if (ext != NULL) {
 						if (0 == strncmp(ext, ".3ds", strlen(ext) < 4 ? strlen(ext) : 4))
 							item[n].type = T_GEOMETRY;
@@ -195,7 +193,7 @@ static int display_dir(const char *dir, int S3DUNUSED(depth), int  posx, int pos
 		}
 		free(namelist);
 	}
-	return(0);
+	return 0;
 }
 
 static int object_click(struct s3d_evt *evt)
@@ -204,7 +202,7 @@ static int object_click(struct s3d_evt *evt)
 	char execstr[256];
 	oid = (int) * ((unsigned long *)evt->buf);
 	printf("!!!!!!!!! clicked object %d\n", oid);
-	for (i = 0;i < n_item;i++) {
+	for (i = 0; i < n_item; i++) {
 		if (((oid == item[i].icon_oid) || (oid == item[i].descr_oid)) ||
 		                (oid == item[i].pie_oid)) {
 			switch (item[i].type) {
@@ -214,26 +212,26 @@ static int object_click(struct s3d_evt *evt)
 				printf("going into %s\n", item[i].name);
 				chdir(item[i].name);
 				display_dir(".", 0, 0, 0, 0);
-				return(0);
+				return 0;
 				break;
 			case T_GEOMETRY:
 				printf("loading geometry %s\n", item[i].name);
 				snprintf(execstr, 256, "modelloader \"%s\"&\n", item[i].name);
 				system(execstr);
-				return(0);
+				return 0;
 				break;
 			case T_MOVIE:
 				printf("playing %s\n", item[i].name);
 				snprintf(execstr, 256, "mplayer -vo s3d \"%s\"&\n", item[i].name);
 				system(execstr);
-				return(0);
+				return 0;
 				break;
 
 
 			}
 		}
 	}
-	return(0);
+	return 0;
 }
 static void mainloop(void)
 {
@@ -256,5 +254,5 @@ int main(int argc, char **argv)
 		s3d_mainloop(mainloop);
 		s3d_quit();
 	}
-	return(0);
+	return 0;
 }
