@@ -1,7 +1,7 @@
 /*
  * io.c
  *
- * Copyright (C) 2004-2008 Simon Wunderlich <dotslash@packetmixer.de>
+ * Copyright (C) 2004-2011  Simon Wunderlich <dotslash@packetmixer.de>
  *
  * This file is part of the s3d API, the API of s3d (the 3d network display server).
  * See http://s3d.berlios.de/ for more updates.
@@ -65,6 +65,11 @@ static void sigint_handler(int S3DUNUSED(sig), int S3DUNUSED(code))  /*  ... ? *
 #endif
 int _s3d_ready = 0;
 
+/** \brief print s3d parameter
+ *
+ * Prints the possible parameter for the client library (which can be passed in
+ * s3d_init())
+ */
 void s3d_usage(void)
 {
 	printf("s3d-parameters:\n");
@@ -83,7 +88,7 @@ static int parse_args(int *argc, char ***argv)
 		{"s3d-help", 0, NULL, 'h'},
 		{NULL, 0, NULL, 0}
 	};
-	if ((argc == NULL) || (argv == NULL)) return(0); /* nothing to parse */
+	if ((argc == NULL) || (argv == NULL)) return 0; /* nothing to parse */
 	old_argc = *argc;
 	optind = 0;
 	opterr = 0; /* we don't want to be bothered if there is some error */
@@ -102,7 +107,7 @@ static int parse_args(int *argc, char ***argv)
 		case 'h':
 			printf("usage: %s [options]", (*argv)[0]);
 			s3d_usage();
-			return(-1);
+			return -1;
 		default:
 			/* ignore args which are not for us, but maybe the app which builds on us */
 			(*argv)[(*argc)] = (*argv)[curopt];
@@ -116,9 +121,27 @@ static int parse_args(int *argc, char ***argv)
 		(*argc)++;
 	}
 	optind = 0;
-	return(0);
+	return 0;
 }
 /*  external functions go here ... */
+/** \brief initialize s3d library
+ *
+ * This will initialize the s3d-library and the connection to the Server. It
+ * will return 0 on success in server initialization. name specifies the your
+ * programs name.
+ *
+ * \code
+ * int main(char argc, char **argv)
+ * {
+ *         if (!s3d_init(&argc, &argv, "Hello world"))
+ *         {
+ *                 ...
+ *                 s3d_quit();
+ *         }
+ *         return 0;
+ * }
+ * \endcode
+ */
 int s3d_init(int *argc, char ***argv, const char *name)
 {
 	char     *s;
@@ -141,16 +164,16 @@ int s3d_init(int *argc, char ***argv, const char *name)
 		if (s3d_net_init(urlc) == CON_NULL) {
 			strncpy(urlc, "s3d://127.0.0.1:6066/", 256);
 			if (s3d_net_init(urlc) == CON_NULL)
-				return(-1);
+				return -1;
 		}
 	} else {
 		strncpy(urlc, url, 256);  /*  this should keep buffer overflows away, maybe */
 		urlc[255] = '\0';  /*  just to make sure */
 		if (!strncmp(urlc, "s3d:// ", 6)) {
-			if (s3d_net_init(urlc) == CON_NULL) return(-1);
+			if (s3d_net_init(urlc) == CON_NULL) return -1;
 		} else {
 			errs("s3d_init()", "invalid url");
-			return(-1);
+			return -1;
 		}
 	}
 	strncpy(buf, name, 256);  /*  copy the name ... */
@@ -164,17 +187,22 @@ int s3d_init(int *argc, char ***argv, const char *name)
 	if (signal(SIGTERM, (sig_t)sigint_handler) == SIG_ERR)
 		errdn(LOW, "s3d_init():signal()", errno);
 #endif
-	for (i = 0;i < 100;i++) {
+	for (i = 0; i < 100; i++) {
 		s3d_net_check(); /* wait for init packet */
 		nanosleep(&t, NULL);
 		if (_s3d_ready) {
 			cb_lock--;
-			return(0);
+			return 0;
 		}
 	}
-	return(-1);
+	return -1;
 }
-/*  shuts down the socket, clearing the stack */
+
+/** \brief shutdown s3d library
+ *
+ * Closes the connection and clears the event-stack. It can also be used to
+ * leave the s3d_mainloop().
+ */
 int s3d_quit(void)
 {
 	struct s3d_evt *ret;
@@ -203,10 +231,26 @@ int s3d_quit(void)
 		ret->length = 0;
 		s3d_push_event(ret);
 	}
-	return(0);
+	return 0;
 }
-/*  apps should use that as main loop for their programs. */
-int s3d_mainloop(void (*f)())
+
+/** \brief set mainloop of program
+ *
+ * Takes a function as argument. It will loop this function until a quit-event
+ * is received. You can pass NULL if you have no function to be looped, but its
+ * better to sleep some time if you have nothing to do anyway to save cpu-time.
+ *
+ * \code
+ * void mainloop(void)
+ * {
+ *         usleep(1000); // sleep 1 ms in every cycle
+ * }
+ * ...
+ *
+ * s3d_mainloop(mainloop());
+ * \endcode
+ */
+int s3d_mainloop(void (*f)(void))
 {
 	while (con_type != CON_NULL) {
 		cb_lock++;   /* no callbacks while we are in mainloop */
@@ -215,42 +259,47 @@ int s3d_mainloop(void (*f)())
 		s3d_process_stack();
 		s3d_net_check();  /* get any other packets we might have missed */
 	}
-	return(0);
+	return 0;
 }
-/*  opens a file returning it's filesize  */
-/*  and setting *pointer to the buffer. to be freed */
+
+/** \brief copy file into memory
+ *
+ * This opens the file fname, setting *pointer to it's memory position. the
+ * function will return the size of buffer. you can free() the pointer when
+ * you're finished.
+ */
 int s3d_open_file(const char *fname, char **pointer)
 {
 	FILE *fp;
 	char *buf = NULL;
-	int filesize;
+	size_t filesize;
+	size_t read_items;
 	struct stat bf;
 	*pointer = NULL;
-	/* if ((fp = fopen(fname, "rb")) == NULL)
-	 { errn("s3d_open_file():fopen()",errno); return(0);}
-	 if (fseek(fp, 0, SEEK_END) != 0)
-	 { errn("s3d_open_file():fseek()",errno); return(0);}
-	 if ((filesize = (int)ftell(fp)) == (long)-1)
-	 { errn("s3d_open_file():ftell()",errno); return(0);}
-	 if (fseek(fp, 0, SEEK_SET) != 0)
-	 { errn("s3d_open_file():fseek()",errno); return(0);}*/
 
 	if ((fp = fopen(fname, "rb")) == NULL) {
 		errdn(VLOW, "s3d_open_file():fopen()", errno);
-		return(-1);
+		return -1;
 	}
 	if (fstat(fileno(fp), &bf)) {
 		errdn(VLOW, "s3d_open_file():fstat()", errno);
+		fclose(fp);
 		return(-1);
 	}
 	filesize = bf.st_size;
-	/* s3dprintf(LOW, "opening %s, filesize is %d",fname, filesize);*/
 	if ((buf = (char *)malloc(filesize)) == NULL) {
 		errn("s3d_open_3ds_file():malloc()", errno);
 		exit(-1);
 	}
-	fread(buf, 1, filesize, fp);
+	read_items = fread(buf, 1, filesize, fp);
 	fclose(fp);
+
+	if (read_items != filesize) {
+		errdn(VLOW, "s3d_open_file():fread()", errno);
+		free(buf);
+		return -1;
+	}
+
 	*pointer = buf;
-	return(filesize);
+	return filesize;
 }
