@@ -1,7 +1,7 @@
 /*
  * modelread.c
  *
- * Copyright (C) 2004-2008 Simon Wunderlich <dotslash@packetmixer.de>
+ * Copyright (C) 2004-2011  Simon Wunderlich <dotslash@packetmixer.de>
  *
  * This file is part of the s3d API, the API of s3d (the 3d network display server).
  * See http://s3d.berlios.de/ for more updates.
@@ -43,14 +43,21 @@ static struct material2texture *mat2tex_root = NULL;
 
 #define MAXSTRN  20
 static int model_load(char *file);
-/*  just a helper function for reading from file instead of memory. */
+/** \brief read model from file
+ *
+ * Imports an 3d object file and returns the object number. Quite a number of
+ * formats are supported, like 3D Studio (.3ds, .prj), Lightwave (.lw, .lwb,
+ * .lwo), Quake Models (.md3), or simply everything libg3d supports. :)
+ *
+ * \remarks Of course, you won't forget to toggle it visible, won't you?
+ */
 int s3d_import_model_file(const char *fname)
 {
 	char *buf, *ptr, *next;
 	char searchpath[1024];
 	char path[1024];
 	int oid;
-	if (fname == NULL) return(-1);
+	if (fname == NULL) return -1;
 #ifndef OBJSDIR
 #define OBJSDIR  ":./:../:../../:/usr/local/share/s3d/:/usr/share/s3d/"
 #endif
@@ -70,7 +77,7 @@ int s3d_import_model_file(const char *fname)
 			strcat(path, fname);
 			if (s3d_open_file(path, &buf) != -1) { /* found something */
 				free(buf); /* TODO: badbadbad ... */
-				if (-1 != (oid = model_load(path))) return(oid);
+				if (-1 != (oid = model_load(path))) return oid;
 
 			}
 		}
@@ -78,14 +85,13 @@ int s3d_import_model_file(const char *fname)
 			ptr = next;     /* move pointer to the next position */
 	}
 	errds(LOW, "s3d_import_model_file()", "Could not open %s", fname);
-	return(-1); /* nothing in search path ... */
+	return -1; /* nothing in search path ... */
 }
 
-static struct material2texture* get_mat2tex(struct material2texture **mat2tex, void *mat_ptr)
-{
+static struct material2texture* get_mat2tex(struct material2texture **mat2tex, void *mat_ptr) {
 	while ((*mat2tex) != NULL) {
 
-		if ((*mat2tex)->material_ptr == mat_ptr) return (*mat2tex);
+		if ((*mat2tex)->material_ptr == mat_ptr) return *mat2tex;
 
 		mat2tex = &(*mat2tex)->next_ptr;
 
@@ -106,11 +112,11 @@ static struct material2texture* get_mat2tex(struct material2texture **mat2tex, v
 		(*mat2tex)->material_id = -1;
 		(*mat2tex)->texture_id = -1;
 
-		return (*mat2tex);
+		return *mat2tex;
 
 	}
 
-	return(NULL);
+	return NULL;
 
 }
 
@@ -264,6 +270,6 @@ static int model_load(char *file)
 	}
 	g3d_context_free(context);
 
-	return(obj_id);
+	return obj_id;
 }
 
