@@ -1,7 +1,7 @@
 /*
  * network.c
  *
- * Copyright (C) 2004-2008 Simon Wunderlich <dotslash@packetmixer.de>
+ * Copyright (C) 2004-2011  Simon Wunderlich <dotslash@packetmixer.de>
  *
  * This file is part of the s3d API, the API of s3d (the 3d network display server).
  * See http://s3d.berlios.de/ for more updates.
@@ -56,15 +56,22 @@ int net_send(uint8_t opcode, char *buf, uint16_t length)
 		break;
 #endif
 	}
-	return(0);
+	return 0;
 }
 /* handler for socket based connection types */
 #ifdef TCP
 static int _s3d_net_receive(void)
 {
-	return(_s3d_tcp_net_receive());
+	return _s3d_tcp_net_receive();
 }
 #endif
+/** \brief get events from server
+ *
+ * This functions is for programs which do not employ a mainloop, hence they
+ * need to check for new events on their own. Programs like these must make sure
+ * to call this function from time to time to convince the server that they did
+ * not freeze or bail out.
+ */
 int s3d_net_check(void)
 {
 	switch (con_type) {
@@ -87,7 +94,7 @@ int s3d_net_check(void)
 #endif
 	}
 	s3d_process_stack();
-	return(0);
+	return 0;
 }
 int s3d_net_init(char *urlc)
 {
@@ -124,9 +131,8 @@ int s3d_net_init(char *urlc)
 	} else {
 		if (first_slash < port)
 			tcp = 0;
-		else
-			if (first_slash != NULL)
-				*first_slash = 0;
+		else if (first_slash != NULL)
+			*first_slash = 0;
 		if (!strncmp(port, "shm", 3)) {
 			tcp = 0; /* null the others */
 		} else {
@@ -136,7 +142,7 @@ int s3d_net_init(char *urlc)
 #ifdef SHM
 	if (shm) {
 		if (!strncmp(port, "shm", 3))
-			if (!_shm_init(sv)) return(con_type = CON_SHM);
+			if (!_shm_init(sv)) return con_type = CON_SHM;
 	}
 #endif
 #ifdef TCP
@@ -148,8 +154,8 @@ int s3d_net_init(char *urlc)
 				pn = 6066;
 			}
 		}
-		if (!_tcp_init(sv, pn)) return(con_type = CON_TCP);
+		if (!_tcp_init(sv, pn)) return con_type = CON_TCP;
 	}
 #endif
-	return(CON_NULL);
+	return CON_NULL;
 }
