@@ -1,7 +1,7 @@
 /*
  * proto_in.c
  *
- * Copyright (C) 2004-2008 Simon Wunderlich <dotslash@packetmixer.de>
+ * Copyright (C) 2004-2011  Simon Wunderlich <dotslash@packetmixer.de>
  *
  * This file is part of the s3d API, the API of s3d (the 3d network display server).
  * See http://s3d.berlios.de/ for more updates.
@@ -186,6 +186,6 @@ int net_prot_in(uint8_t opcode, uint16_t length, char *buf)
 
 		s3d_push_event(s3devt);
 	}
-	return(0);
+	return 0;
 }
 
