@@ -1,7 +1,7 @@
 /*
  * s3dlib.h
  *
- * Copyright (C) 2004-2008 Simon Wunderlich <dotslash@packetmixer.de>
+ * Copyright (C) 2004-2011  Simon Wunderlich <dotslash@packetmixer.de>
  *
  * This file is part of the s3d API, the API of s3d (the 3d network display server).
  * See http://s3d.berlios.de/ for more updates.
@@ -21,6 +21,8 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
+#ifndef _S3DLIB_H_
+#define _S3DLIB_H_
 
 #include <stdint.h>
 #include "config.h"
@@ -41,10 +43,10 @@
 #endif
 #endif
 
-#ifdef HAVE_GCCVISIBILITY
-#define S3DEXPORT __attribute__ ((visibility("default")))
+#ifdef __GNUC_MINOR__
+#define S3D_FORMAT(type, fmt_pos, arg_pos)  __attribute__ ((format (type, fmt_pos, arg_pos)))
 #else
-#define S3DEXPORT
+#define S3D_FORMAT(type, fmt_pos, arg_pos)
 #endif
 
 #define VLOW 1
@@ -96,10 +98,14 @@ struct s3d_tex {
 } __attribute__((__packed__));
 
 #ifdef DEBUG
-S3DEXPORT void s3dprintf(int relevance, const char *fmt, ...);
+S3DEXPORT void s3dprintf(int relevance, const char *fmt, ...) S3D_FORMAT(printf, 2, 3);
 S3DEXPORT void errdn(int relevance, const char *func, int en);
-S3DEXPORT void errds(int relevance, const char *func, const char *fmt, ...);
+S3DEXPORT void errds(int relevance, const char *func, const char *fmt, ...) S3D_FORMAT(printf, 3, 4);
 #else
+static void s3dprintf(int relevance, const char *fmt, ...) S3D_FORMAT(printf, 2, 3);
+static void errdn(int relevance, const char *func, int en);
+static void errds(int relevance, const char *func, const char *fmt, ...) S3D_FORMAT(printf, 3, 4);
+
 static __inline__ void s3dprintf(int S3DUNUSED(relevance),
                                  const char *S3DUNUSED(fmt), ...) {}
 static __inline__ void errdn(int S3DUNUSED(relevance),
@@ -133,7 +139,7 @@ int s3d_net_init(char *urlc);
 int _s3d_update_texture(int object, uint32_t tex, uint16_t xpos, uint16_t ypos, uint16_t w, uint16_t h);
 #ifdef TCP
 /* tcp.c */
-int _tcp_init(char *sv, int pn);
+int _tcp_init(const char *sv, int pn);
 int _tcp_quit(void);
 int _s3d_tcp_net_receive(void);
 int tcp_writen(char *str, int s);
@@ -179,3 +185,5 @@ void htonlb(uint32_t* netint32, int num);
 void ntohlb(uint32_t* netint32, int num);
 void htonsb(uint16_t* netint16, int num);
 void ntohsb(uint16_t* netint16, int num);
+
+#endif /* _S3DLIB_H_ */
