@@ -1,8 +1,8 @@
 /*
  * sei_construct.c
  *
- * Copyright (C) 2006-2008 Simon Wunderlich <dotslash@packetmixer.de>
- * Copyright (C) 1994 A. Narkhede and D .Manocha, who released their code
+ * Copyright (C) 2006-2011  Simon Wunderlich <dotslash@packetmixer.de>
+ * Copyright (C) 1994  A. Narkhede and D .Manocha, who released their code
  * for public domain:
  * <snip>
  *
@@ -116,13 +116,13 @@ int _greater_than(point_t *v0, point_t *v1)
 	else if (v0->y < v1->y - C_EPS)
 		return FALSE;
 	else
-		return (v0->x > v1->x);
+		return v0->x > v1->x;
 }
 
 
 int _equal_to(point_t *v0, point_t *v1)
 {
-	return (FP_EQUAL(v0->y, v1->y) && FP_EQUAL(v0->x, v1->x));
+	return FP_EQUAL(v0->y, v1->y) && FP_EQUAL(v0->x, v1->x);
 }
 
 int _greater_than_equal_to(point_t *v0, point_t *v1)
@@ -132,7 +132,7 @@ int _greater_than_equal_to(point_t *v0, point_t *v1)
 	else if (v0->y < v1->y - C_EPS)
 		return FALSE;
 	else
-		return (v0->x >= v1->x);
+		return v0->x >= v1->x;
 }
 
 int _less_than(point_t *v0, point_t *v1)
@@ -142,7 +142,7 @@ int _less_than(point_t *v0, point_t *v1)
 	else if (v0->y > v1->y + C_EPS)
 		return FALSE;
 	else
-		return (v0->x < v1->x);
+		return v0->x < v1->x;
 }
 
 
@@ -207,10 +207,10 @@ static int init_query_structure(int segnum)
 
 	tr[t1].hi = tr[t2].hi = tr[t4].lo = qs[i1].yval;
 	tr[t1].lo = tr[t2].lo = tr[t3].hi = qs[i3].yval;
-	tr[t4].hi.y = (double)(INFINITY);
-	tr[t4].hi.x = (double)(INFINITY);
-	tr[t3].lo.y = (double) - 1 * (INFINITY);
-	tr[t3].lo.x = (double) - 1 * (INFINITY);
+	tr[t4].hi.y = HUGE_VAL;
+	tr[t4].hi.x = HUGE_VAL;
+	tr[t3].lo.y = -HUGE_VAL;
+	tr[t3].lo.x = -HUGE_VAL;
 	tr[t1].rseg = tr[t2].lseg = segnum;
 	tr[t1].u0 = tr[t2].u0 = t4;
 	tr[t1].d0 = tr[t2].d0 = t3;
@@ -308,8 +308,8 @@ int locate_endpoint(point_t *v, point_t *vo, int r)
 	case T_Y:
 		if (_greater_than(v, &rptr->yval)) /* above */
 			return locate_endpoint(v, vo, rptr->right);
-		else if (_equal_to(v, &rptr->yval)) /* the point is already */
-		{             /* inserted. */
+		else if (_equal_to(v, &rptr->yval)) { /* the point is already */
+			/* inserted. */
 			if (_greater_than(vo, &rptr->yval)) /* above */
 				return locate_endpoint(v, vo, rptr->right);
 			else
@@ -340,7 +340,7 @@ int locate_endpoint(point_t *v, point_t *vo, int r)
 		errs("sei:locate_endpoint()", "Haggu!!!! (whatever)");
 		break;
 	}
-	return(-1);
+	return -1;
 }
 
 
@@ -368,8 +368,8 @@ static int merge_trapezoids(int segnum, int tfirst, int tlast, int side)
 
 		if (cond) {
 			if ((tr[t].lseg == tr[tnext].lseg) &&
-			                (tr[t].rseg == tr[tnext].rseg)) /* good neighbours */
-			{                 /* merge them */
+			                (tr[t].rseg == tr[tnext].rseg)) { /* good neighbours */
+				/* merge them */
 				/* Use the upper node as the new node i.e. t */
 
 				ptnext = qs[tr[tnext].sink].parent;
@@ -544,8 +544,8 @@ static int add_segment(int segnum)
 		tr[tu].sink = i1;
 		tr[tl].sink = i2;
 		tlast = tu;
-	} else    /* v1 already present */
-	{       /* Get the lowermost intersecting trapezoid */
+	} else {  /* v1 already present */
+		/* Get the lowermost intersecting trapezoid */
 		tlast = locate_endpoint(&s.v1, &s.v0, s.root1);
 		tribot = 1;
 	}
