@@ -1,8 +1,8 @@
 /*
  * sei_monotone.c
  *
- * Copyright (C) 2006-2008 Simon Wunderlich <dotslash@packetmixer.de>
- * Copyright (C) 1994 A. Narkhede and D .Manocha, who released their code
+ * Copyright (C) 2006-2011  Simon Wunderlich <dotslash@packetmixer.de>
+ * Copyright (C) 1994  A. Narkhede and D .Manocha, who released their code
  * for public domain:
  * <snip>
  *
@@ -77,7 +77,7 @@ static int inside_polygon(trap_t *t)
 
 	if (((t->u0 <= 0) && (t->u1 <= 0)) ||
 	                ((t->d0 <= 0) && (t->d1 <= 0))) /* triangle */
-		return (_greater_than(&seg[rseg].v1, &seg[rseg].v0));
+		return _greater_than(&seg[rseg].v1, &seg[rseg].v0);
 
 	return 0;
 }
@@ -110,7 +110,7 @@ static double get_angle(point_t *vp0, point_t *vpnext, point_t *vp1)
 	if (CROSS_SINE(v0, v1) >= 0) /* sine is positive */
 		return DOT(v0, v1) / LENGTH(v0) / LENGTH(v1);
 	else
-		return (-1.0 * DOT(v0, v1) / LENGTH(v0) / LENGTH(v1) - 2);
+		return -1.0 * DOT(v0, v1) / LENGTH(v0) / LENGTH(v1) - 2;
 }
 
 
@@ -247,27 +247,6 @@ int monotonate_trapezoids(int n)
 	/* Initialise the mon data-structure and start spanning all the */
 	/* trapezoids within the polygon */
 
-#if 0
-	for (i = 1; i <= n; i++) {
-		mchain[i].prev = i - 1;
-		mchain[i].next = i + 1;
-		mchain[i].vnum = i;
-		vert[i].pt = seg[i].v0;
-		vert[i].vnext[0] = i + 1; /* next vertex */
-		vert[i].vpos[0] = i; /* locn. of next vertex */
-		vert[i].nextfree = 1;
-	}
-	mchain[1].prev = n;
-	mchain[n].next = 1;
-	vert[n].vnext[0] = 1;
-	vert[n].vpos[0] = n;
-	chain_idx = n;
-	mon_idx = 0;
-	mon[0] = 1;   /* position of any vertex in the first */
-	/* chain  */
-
-#else
-
 	for (i = 1; i <= n; i++) {
 		mchain[i].prev = seg[i].prev;
 		mchain[i].next = seg[i].next;
@@ -283,8 +262,6 @@ int monotonate_trapezoids(int n)
 	mon[0] = 1;   /* position of any vertex in the first */
 	/* chain  */
 
-#endif
-
 	/* traverse the polygon */
 	if (tr[tr_start].u0 > 0)
 		traverse_polygon(0, tr_start, tr[tr_start].u0, TR_FROM_UP);
@@ -617,15 +594,15 @@ static int triangulate_single_polygon(int nvert, int posmax, int side, int op[][
 				op[op_idx][2] = v;
 				op_idx++;
 				ri--;
-			} else  /* non-convex */
-			{  /* add v to the chain */
+			} else { /* non-convex */
+				/* add v to the chain */
 				ri++;
 				rc[ri] = v;
 				vpos = mchain[vpos].next;
 				v = mchain[vpos].vnum;
 			}
-		} else   /* reflex-chain empty: add v to the */
-		{   /* reflex chain and advance it  */
+		} else { /* reflex-chain empty: add v to the */
+			/* reflex chain and advance it  */
 			rc[++ri] = v;
 			vpos = mchain[vpos].next;
 			v = mchain[vpos].vnum;
