@@ -1,7 +1,7 @@
 /*
  * animate.c
  *
- * Copyright (C) 2006-2008 Simon Wunderlich <dotslash@packetmixer.de>
+ * Copyright (C) 2006-2011  Simon Wunderlich <dotslash@packetmixer.de>
  *
  * This file is part of the s3d Widgets, a Widget Library for s3d.
  * See http://s3d.berlios.de/ for more updates.
@@ -36,10 +36,10 @@ int ani_need_arr = 0;
 int s3dw_ani_stackpos(s3dw_widget *f)
 {
 	int i;
-	for (i = 0;i < ani_n;i++)
+	for (i = 0; i < ani_n; i++)
 		if (ani_s[i] == f)
-			return(i);  /* already in list */
-	return(-1);
+			return i;  /* already in list */
+	return -1;
 
 }
 
@@ -129,8 +129,8 @@ int s3dw_ani_check(s3dw_widget *f)
 	rz = f->arz - f->rz;
 
 	if (((fabs(f->as - f->s) / f->s) > 0.01) || (sqrt(x*x + y*y + z*z) > 0.01) || (sqrt(rx*rx + ry*ry + rz*rz) > 0.01))
-		return(0);
-	return(1);
+		return 0;
+	return 1;
 }
 
 /* need an arrangement ... */
@@ -143,14 +143,32 @@ void s3dw_ani_needarr(void)
 
 }
 
-/* doing the whole animation thing */
+/** \brief doing the whole animation thing
+ *
+ * Just call this in your mainloop if you want some nice window sliding
+ * animations. it's somewhat bloating, but you don't want to miss it ;)
+ *
+ * \code
+ * #include <time.h>   // nanosleep()
+ * static struct timespec t={0.33*1000*1000}; // 33 mili seconds
+ * void mainloop()
+ * {
+ *         // keep this in your mainloop. this will do smooth animations for you ...
+ *         s3dw_ani_mate();
+ *         nanosleep(&t,NULL);
+ * }
+ *
+ * ....
+ * s3d_mainloop(mainloop);
+ * \endcode
+ */
 void s3dw_ani_mate(void)
 {
 	int i;
 	s3dw_widget *f;
 	animation_on = 1; /* animation is activated */
 	if (ani_need_arr) s3dw_arrange();
-	for (i = 0;i < ani_n;i++) {
+	for (i = 0; i < ani_n; i++) {
 		f = ani_s[i];
 		s3dw_ani_iterate(f);
 		if (s3dw_ani_check(f)) {
