@@ -1,7 +1,7 @@
 /*
  * button.c
  *
- * Copyright (C) 2006-2008 Simon Wunderlich <dotslash@packetmixer.de>
+ * Copyright (C) 2006-2011  Simon Wunderlich <dotslash@packetmixer.de>
  *
  * This file is part of the s3d Widgets, a Widget Library for s3d.
  * See http://s3d.berlios.de/ for more updates.
@@ -86,7 +86,13 @@ void s3dw_button_draw(s3dw_widget *widget)
 	widget->height = 2;
 }
 
-/* create a new button in the surface */
+/** \brief create a new button in the surface
+ *
+ * Creates a new button on the surface, with "text" written on it and the upper
+ * left corner at (posx,posy) on the surface.
+ *
+ * See s3dw_button for information about callbacks which may be defined.
+ */
 s3dw_button *s3dw_button_new(const s3dw_surface *surface, const char *text, float posx, float posy)
 {
 	s3dw_button *button;
@@ -102,7 +108,7 @@ s3dw_button *s3dw_button_new(const s3dw_surface *surface, const char *text, floa
 
 	s3dw_widget_append((s3dw_widget *)surface, widget);
 	s3dw_button_draw(widget);
-	return(button);
+	return button;
 }
 /* show, make visible */
 void s3dw_button_show(s3dw_widget *widget)
@@ -137,7 +143,7 @@ void s3dw_button_destroy(s3dw_widget *widget)
 /* handle key events */
 int s3dw_button_event_key(s3dw_widget *S3DUNUSED(widget), struct s3d_key_event *S3DUNUSED(keys))
 {
-	return(0);
+	return 0;
 }
 
 /* handle click on a button */
@@ -146,7 +152,7 @@ int s3dw_button_event_click(s3dw_widget *widget, uint32_t oid)
 	s3dw_button *button = (s3dw_button *)widget;
 	if ((button->oid_text == oid) || (widget->oid == oid)) {
 		button->onclick(widget);
-		return(1);
+		return 1;
 	}
-	return(0);
+	return 0;
 }
