@@ -1,7 +1,7 @@
 /*
  * graphics.c
  *
- * Copyright (C) 2004-2008 Simon Wunderlich <dotslash@packetmixer.de>
+ * Copyright (C) 2004-2011  Simon Wunderlich <dotslash@packetmixer.de>
  *
  * This file is part of s3d, a 3d network display server.
  * See http://s3d.berlios.de/ for more updates.
@@ -22,20 +22,21 @@
  */
 
 #include "global.h"
-#include <string.h>   /*  memcpy() */
-
-#include <GL/gl.h>   /*  GLint */
-#include <GL/glext.h>   /*  GL_RESCALE_NORMAL */
-#ifdef G_SDL
-#include <SDL.h>  /*  SDL_GL_SwapBuffers */
+#include <string.h>		/*  memcpy() */
+#if G_SDL
+#include <SDL_opengl.h>		/*  GL_RESCALE_NORMAL */
+#include <SDL.h>		/*  SDL_GL_SwapBuffers */
+#else
+#include <GL/gl.h>		/*  GLint */
+#include <GL/glext.h>		/*  GL_RESCALE_NORMAL */
 #endif
-#include <math.h>   /*  sin(),cos() */
+#include <math.h>		/*  sin(),cos() */
 #ifndef INFINITY
 #define INFINITY 1<<30
 #endif
 /*  this file handles graphics routines */
 /*  local prototypes ... */
-void render_virtual_object(struct t_obj *o);
+static void render_virtual_object(struct t_obj *o);
 /*  ... and types/variables */
 static int select_mode = 0;
 int winw, winh;
@@ -44,7 +45,7 @@ int winw, winh;
 
 int graphics_init(void)
 {
-	GLfloat shin[] = {16.0};
+	GLfloat shin[] = { 16.0 };
 	switch (frame_mode) {
 #ifdef G_SDL
 	case FRAME_SDL:
@@ -52,7 +53,7 @@ int graphics_init(void)
 		break;
 #endif
 	default:
-		return(-1);
+		return -1;
 	}
 	/* light */
 	glEnable(GL_LIGHTING);
@@ -60,7 +61,6 @@ int graphics_init(void)
 
 	/* depth test */
 	glEnable(GL_DEPTH_TEST);
-	/*     glDepthFunc( GL_LEQUAL ); */
 
 	/* textures */
 	glTexEnvf(GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_DECAL);
@@ -75,29 +75,26 @@ int graphics_init(void)
 
 	/* polygon smoothing */
 	glDisable(GL_POLYGON_SMOOTH);
-	/*    glEnable(GL_POLYGON_SMOOTH);
-	    glHint(GL_POLYGON_SMOOTH_HINT, GL_NICEST); */
 
 	/* normalizing */
 	glDisable(GL_AUTO_NORMAL);
-	glDisable(GL_NORMALIZE);   /* don't use the expensive GL_NORMALIZE, we use uniform scaling so GL_RESCALE_NORMAL is sufficent */
+	glDisable(GL_NORMALIZE);	/* don't use the expensive GL_NORMALIZE, we use uniform scaling so GL_RESCALE_NORMAL is sufficent */
 	glEnable(GL_RESCALE_NORMAL);
 
 	/* blending */
 	glEnable(GL_BLEND);
 	glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
-	/*    glBlendFunc(GL_SRC_ALPHA_SATURATE, GL_ONE);*/
 
 	/* set shininess */
-	/*  glMaterialfv(GL_FRONT_AND_BACK,GL_SHININESS,shin); */
 	glMaterialfv(GL_FRONT, GL_SHININESS, shin);
 	graphics_reshape(X_RES, Y_RES);
 
 	/* face culling */
 	glCullFace(GL_FRONT);
 	glEnable(GL_CULL_FACE);
-	return(0);
+	return 0;
 }
+
 /*  this is to be called when the window is resized or created ... */
 void graphics_reshape(int w, int h)
 {
@@ -107,14 +104,15 @@ void graphics_reshape(int w, int h)
 	glMatrixMode(GL_PROJECTION);
 	glLoadIdentity();
 	if (w > h)
-		glFrustum(-((1.0*w) / h), (1.0*w) / h, -1.0, 1.0, 1.0, 5000);
+		glFrustum(-((1.0 * w) / h), (1.0 * w) / h, -1.0, 1.0, 1.0, 5000);
 	else
-		glFrustum(-1.0, 1.0, -(1.0*h) / w, (1.0*h) / w, 1.0, 5000);
+		glFrustum(-1.0, 1.0, -(1.0 * h) / w, (1.0 * h) / w, 1.0, 5000);
 	glMatrixMode(GL_MODELVIEW);
 	if (procs_p != NULL)
 		event_cam_changed();
 }
-void render_virtual_object(struct t_obj *o)
+
+static void render_virtual_object(struct t_obj *o)
 {
 	struct t_process *ap;
 	struct t_vertex x, y;
@@ -125,15 +123,15 @@ void render_virtual_object(struct t_obj *o)
 	glMultMatrixf(o->m);
 	glGetFloatv(GL_MODELVIEW_MATRIX, m);
 	cull_get_planes();
-	if (NULL == (ap = get_proc_by_pid(o->virtual_pid))) { /*  the clean way */
-		errds(HIGH, "render_by_mcp()", "not existing pid (%p) referenced by mcp-object!!", (void*)o);
+	if (NULL == (ap = get_proc_by_pid(o->virtual_pid))) {	/*  the clean way */
+		errds(HIGH, "render_by_mcp()", "not existing pid (%p) referenced by mcp-object!!", (void *)o);
 	} else {
 		/*  now go throu the objects of our app  */
-		for (j = 0;j < ap->n_obj;j++) {
+		for (j = 0; j < ap->n_obj; j++) {
 			if (ap->object[j] != NULL) {
-				if (((select_mode == 0) && ap->object[j]->oflags&OF_VISIBLE) || ((select_mode == 1) && (ap->object[j]->oflags&OF_SELECTABLE))) { /* either select mode is off or it's selectable */
+				if (((select_mode == 0) && ap->object[j]->oflags & OF_VISIBLE) || ((select_mode == 1) && (ap->object[j]->oflags & OF_SELECTABLE))) {	/* either select mode is off or it's selectable */
 					x.x = x.y = x.z = 0.0f;
-					mySetMatrix(ap->object[j]->m); /* get into position ... */
+					mySetMatrix(ap->object[j]->m);	/* get into position ... */
 					myTransformV(&x);
 					y.x = 1.0;
 					y.y = y.z = 0.0f;
@@ -144,7 +142,6 @@ void render_virtual_object(struct t_obj *o)
 
 					k = cull_sphere_in_frustum(&x, ap->object[j]->r * sqrt(y.x * y.x + y.y * y.y + y.z * y.z));
 					if (k) {
-						/*      s3dprintf(HIGH,"object %d is in %s frustum",j,k?"":"not");*/
 						if (select_mode == 1)
 							glPushName(j);
 						obj_render(ap, j);
@@ -157,6 +154,7 @@ void render_virtual_object(struct t_obj *o)
 	}
 	glPopMatrix();
 }
+
 /*  this functions renders by going from mcp objects [as it should be],  */
 /*  recursively positiniong the objects into the space. */
 int render_by_mcp(void)
@@ -166,11 +164,11 @@ int render_by_mcp(void)
 	struct t_obj *o;
 	struct t_vertex x, y;
 	int k;
-	for (i = 0 ; i < p->n_obj ; i++) {  /* check all mcp objects ... */
+	for (i = 0; i < p->n_obj; i++) {	/* check all mcp objects ... */
 		o = p->object[i];
 		if (o != NULL) {
-			if ((select_mode == 0 && o->oflags&OF_VISIBLE) || (select_mode == 1 && o->oflags&OF_SELECTABLE)) { /*  it's even visible ;) */
-				if (o->oflags&OF_VIRTUAL) { /*  we have an app here. */
+			if ((select_mode == 0 && o->oflags & OF_VISIBLE) || (select_mode == 1 && o->oflags & OF_SELECTABLE)) {	/*  it's even visible ;) */
+				if (o->oflags & OF_VIRTUAL) {	/*  we have an app here. */
 					if (o->r != 0.0) {
 						cull_get_planes();
 						mySetMatrix(o->m);
@@ -197,14 +195,14 @@ int render_by_mcp(void)
 							}
 						}
 					}
-				} else if ((o->oflags&OF_CLONE) && (p->object[o->clone_ooid]->oflags&OF_VIRTUAL)) { /* it's a clone of an app */
+				} else if ((o->oflags & OF_CLONE) && (p->object[o->clone_ooid]->oflags & OF_VIRTUAL)) {	/* it's a clone of an app */
 					if (select_mode == 1)
-						glLoadName(o->clone_ooid);/*TODO: what to do if a clone is selected?! */
+						glLoadName(o->clone_ooid);	/*TODO: what to do if a clone is selected?! */
 					glPushMatrix();
 					render_virtual_object(o);
 					render_virtual_object(p->object[o->clone_ooid]);
 					glPopMatrix();
-				} else { /* it's a "regular" mcp object */
+				} else {	/* it's a "regular" mcp object */
 					if (select_mode == 1) {
 						s3dprintf(VLOW, "mcp object no. %d", i);
 						glLoadName(-1);
@@ -217,8 +215,9 @@ int render_by_mcp(void)
 			}
 		}
 	}
-	return(0);
+	return 0;
 }
+
 /* this picks objects from their screen-positions and sends
  * OBK_CLICK-events for the selected object(s).
  * TODO: how big should the select buffer be? */
@@ -250,18 +249,14 @@ int graphics_pick_obj(int x, int y)
 		xpos = ((x - winw / 2.0) / (winw / 2.0));
 		ypos = (((winh - y) - winh / 2.0) / (winh / 2.0)) * (((double)winh / winw));
 	}
-#define mnear 0.001  /*  omg this is so dirty ... but works after all */
+#define mnear 0.001		/*  omg this is so dirty ... but works after all */
 	glFrustum(xpos - mnear, xpos + mnear, ypos - mnear, ypos + mnear, 1, 5000);
 	glMatrixMode(GL_MODELVIEW);
-	glLoadIdentity();  /*  get into position ... */
+	glLoadIdentity();	/*  get into position ... */
 	mySetMatrix(p->object[0]->m);
 	myInvert();
 	myGetMatrix(m);
 	glMultMatrixf(m);
-	/*
-	 glRotatef(-cam.rotate.x, 1.0,0.0,0.0);
-	 glRotatef(-cam.rotate.y, 0.0,1.0,0.0);
-	 glTranslatef(-cam.translate.x,-cam.translate.y,-cam.translate.z);*/
 
 	glInitNames();
 	glPushName(0);
@@ -274,65 +269,63 @@ int graphics_pick_obj(int x, int y)
 		ptr = select_buf;
 		mcp_o = o = names = -1;
 		/* check all the hits, only select the nearest ... */
-		for (i = 0 ; i < hits ; i++) {
+		for (i = 0; i < hits; i++) {
 			names = *ptr;
 			ptr++;
-			z1 = (float) * ptr / 0x7fffffff;
+			z1 = (float)*ptr / 0x7fffffff;
 			ptr++;
-			z2 = (float) * ptr / 0x7fffffff;
+			z2 = (float)*ptr / 0x7fffffff;
 			ptr++;
 			if (z1 < big) {
 				mcp_o = o = -1;
-				for (j = 0;j < names;j++) {
+				for (j = 0; j < names; j++) {
 					switch (j) {
 					case 0:
 						mcp_o = *ptr;
 						break;
 					case 1:
-						o =  *ptr;
+						o = *ptr;
 						break;
 					}
 					ptr++;
 				}
 				big = z1;
 			} else
-				for (j = 0;j < names;j++)
+				for (j = 0; j < names; j++)
 					ptr++;
 			s3dprintf(VLOW, "[HIT %d] names %d [z1:%f|z2:%f] mcp_o=%d, o=%d ", i, names, z1, z2, mcp_o, o);
 		}
 		s3dprintf(VLOW, "mcp_o= %d, o= %d", mcp_o, o);
-		if (mcp_o == -1) { /* it's an mcp object */
+		if (mcp_o == -1) {	/* it's an mcp object */
 			s3dprintf(LOW, "clicked on mcp-object no. %d", o);
 			event_obj_click(p, o);
-		} else
-			if ((names > 1) && ((mcp_o >= 0) && (mcp_o < p->n_obj))) { /* it's an usual object */
-				s3dprintf(LOW, "clicked on mcp-object %d, object %d", mcp_o, o);
-				if (p->object[mcp_o] != NULL) { /*  that shouldn't happen anyways ... */
-					obj_debug(get_proc_by_pid(p->object[mcp_o]->virtual_pid), o);
-					event_obj_click(get_proc_by_pid(p->object[mcp_o]->virtual_pid), o);
-				}
+		} else if ((names > 1) && ((mcp_o >= 0) && (mcp_o < p->n_obj))) {	/* it's an usual object */
+			s3dprintf(LOW, "clicked on mcp-object %d, object %d", mcp_o, o);
+			if (p->object[mcp_o] != NULL) {	/*  that shouldn't happen anyways ... */
+				obj_debug(get_proc_by_pid(p->object[mcp_o]->virtual_pid), o);
+				event_obj_click(get_proc_by_pid(p->object[mcp_o]->virtual_pid), o);
 			}
+		}
 	}
 	glMatrixMode(GL_PROJECTION);
 	glPopMatrix();
 	glMatrixMode(GL_MODELVIEW);
 	select_mode = 0;
-	return(0);
+	return 0;
 }
 
-
 void graphics_main(void)
 {
 	struct t_process *p = get_proc_by_pid(MCP);
 	t_mtrx m;
-	GLfloat pos[] = {0, 50, 50, 1.0};
-	GLfloat light0_spec[] = {0.7, 0.7, 0.7, 0.0};
-	GLfloat light0_shininess[] = {1.0};
-	GLfloat light0_diff[] = {0.5, 0.5, 0.5, 1.0};
-	GLfloat light0_amb[] = {1.0, 1.0, 1.0, 1.0};
+	GLfloat pos[] = { 0, 50, 50, 1.0 };
+	GLfloat light0_spec[] = { 0.7, 0.7, 0.7, 0.0 };
+	GLfloat light0_shininess[] = { 1.0 };
+	GLfloat light0_diff[] = { 0.5, 0.5, 0.5, 1.0 };
+	GLfloat light0_amb[] = { 1.0, 1.0, 1.0, 1.0 };
 
 	select_mode = 0;
-	glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);  /*  clear screen */
+	glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);	/*  clear screen */
 	/*  set up the cam ... */
 	glMatrixMode(GL_MODELVIEW);
 
@@ -349,14 +342,9 @@ void graphics_main(void)
 	glMultMatrixf(m);
 	glLightfv(GL_LIGHT0, GL_POSITION, pos);
 
-	/*glRotatef(-cam.rotate.z, 0.0,0.0,1.0);
-	glRotatef(-cam.rotate.x, 1.0,0.0,0.0);
-	glRotatef(-cam.rotate.y, 0.0,1.0,0.0);
-	glTranslatef(-cam.translate.x,-cam.translate.y,-cam.translate.z);*/
-
-	glPushMatrix();  /*  save the cam */
+	glPushMatrix();		/*  save the cam */
 	render_by_mcp();
-	glPopMatrix();  /*  restore the cam */
+	glPopMatrix();		/*  restore the cam */
 	glLoadIdentity();
 	glMultMatrixf(m);
 
@@ -377,5 +365,5 @@ void graphics_main(void)
 /*  quit the graphic-interface */
 int graphics_quit(void)
 {
-	return(0);
+	return 0;
 }
