@@ -1,7 +1,7 @@
 /*
  * graphics_sdl.c
  *
- * Copyright (C) 2004-2008 Simon Wunderlich <dotslash@packetmixer.de>
+ * Copyright (C) 2004-2011  Simon Wunderlich <dotslash@packetmixer.de>
  *
  * This file is part of s3d, a 3d network display server.
  * See http://s3d.berlios.de/ for more updates.
@@ -27,7 +27,7 @@ int aa_level = 4;
 #include <SDL_opengl.h>
 #include <SDL.h>
 
-int SDLFlags = 0;      /*  some flags for SDL */
+int SDLFlags = 0;		/*  some flags for SDL */
 int graphics_init_sdl(void)
 {
 	SDL_Surface *GLwin = NULL;
@@ -38,7 +38,7 @@ int graphics_init_sdl(void)
 	SDLFlags = SDL_OPENGL | SDL_GL_DOUBLEBUFFER | SDL_HWPALETTE | SDL_RESIZABLE;
 	if (SDL_Init(SDL_INIT_VIDEO | SDL_INIT_TIMER) < 0)
 		errsf("SDL_Init()", SDL_GetError());
-	if ((VideoInfo = (SDL_VideoInfo *)SDL_GetVideoInfo()) == NULL)
+	if ((VideoInfo = (SDL_VideoInfo *) SDL_GetVideoInfo()) == NULL)
 		errs("SDL_GetVIdeoInfo()", SDL_GetError());
 	else {
 		if (VideoInfo->hw_available) {
@@ -50,16 +50,16 @@ int graphics_init_sdl(void)
 		}
 		if (VideoInfo->blit_hw)
 			SDLFlags |= SDL_HWACCEL;
-		/*     if(SDL_WM_ToggleFullScreen(GLwin) == 0)         SDLerror("SDL_WM_ToggleFullScreen"); */
 	}
 
-
 	/*  set some opengl-attributes */
 	SDL_GL_SetAttribute(SDL_GL_DOUBLEBUFFER, 1);
 	do {
 		if (aa_level > 0) {
-			if (SDL_GL_SetAttribute(SDL_GL_MULTISAMPLEBUFFERS, 1))   s3dprintf(VHIGH, "error initializing multisampling");
-			if (SDL_GL_SetAttribute(SDL_GL_MULTISAMPLESAMPLES, aa_level)) s3dprintf(VHIGH, "no multisampling available");
+			if (SDL_GL_SetAttribute(SDL_GL_MULTISAMPLEBUFFERS, 1))
+				s3dprintf(VHIGH, "error initializing multisampling");
+			if (SDL_GL_SetAttribute(SDL_GL_MULTISAMPLESAMPLES, aa_level))
+				s3dprintf(VHIGH, "no multisampling available");
 		}
 
 		/*  more opengl-init-stuff */
@@ -88,10 +88,11 @@ int graphics_init_sdl(void)
 	s3dprintf(VLOW, "Extensions : %s", glGetString(GL_EXTENSIONS));
 
 	graphics_reshape(X_RES, Y_RES);
-	return(0);
+	return 0;
 }
+
 int graphics_quit_sdl(void)
 {
 	SDL_Quit();
-	return(0);
+	return 0;
 }
