@@ -1,7 +1,7 @@
 /*
  * main.c
  *
- * Copyright (C) 2004-2008 Simon Wunderlich <dotslash@packetmixer.de>
+ * Copyright (C) 2004-2011  Simon Wunderlich <dotslash@packetmixer.de>
  *
  * This file is part of s3d, a 3d network display server.
  * See http://s3d.berlios.de/ for more updates.
@@ -21,28 +21,28 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-
-#include "global.h"    /*  contains the prototypes of all modules */
-#include <time.h>   /* nanosleep() */
-#include <stdlib.h>   /* exit() */
-#include <unistd.h>   /* sleep(), fork() */
+#include "global.h"		/*  contains the prototypes of all modules */
+#include "config.h"
+#include <time.h>		/* nanosleep() */
+#include <stdlib.h>		/* exit() */
+#include <unistd.h>		/* sleep(), fork() */
 #define  X_RES 800
 #define  Y_RES 600
-#include <getopt.h>   /*  getopt() */
-#include <string.h>   /*  strcmp() */
+#include <getopt.h>		/*  getopt() */
+#include <string.h>		/*  strcmp() */
 #ifdef SIGS
-#include <signal.h>   /*  signal() */
+#include <signal.h>		/*  signal() */
 #endif
-#include <errno.h>   /*  errno() */
+#include <errno.h>		/*  errno() */
 int frame_mode = 0;
 static int kidpid = 0;
 static int norc = 0;
 int running;
 static const char *rc = NULL;
 static const char *homerc = "~/.s3drc";
-static const char *etcrc = "/etc/s3drc";
+static const char *etcrc = S3D_CFG_INSTALL_DIR "/s3drc";
 /*static int father_done=0;*/
-static const char **s3drc[] = {&rc, &homerc, &etcrc};
+static const char **s3drc[] = { &rc, &homerc, &etcrc };
 
 static void mainloop(void);
 #ifdef SIGS
@@ -52,6 +52,7 @@ static void sigint_handler(int S3DUNUSED(sig))
 	s3dprintf(HIGH, "oh my gosh there is a sigint/term signal! running away ...");
 	quit();
 }
+
 static void sigchld_handler(int S3DUNUSED(sig))
 {
 	if (kidpid != 0) {
@@ -61,6 +62,7 @@ static void sigchld_handler(int S3DUNUSED(sig))
 	}
 }
 #endif
+
 static void sigusr_handler(int S3DUNUSED(sig))
 {
 	s3dprintf(HIGH, "father told use he's done, so lets start to think about the rc file ...");
@@ -72,8 +74,8 @@ int rc_init(void)
 #ifdef SIGS
 	int ret, i;
 	struct timespec t = {
-		0, 10*1000*1000
-	}; /* 10 mili seconds */
+		0, 10 * 1000 * 1000
+	};			/* 10 mili seconds */
 	kidpid = fork();
 	if (kidpid == -1) {
 		errsf("rc_init()", "*sobsob*, can't fork");
@@ -87,7 +89,7 @@ int rc_init(void)
 		 * and all his sockets up */
 		while (!running)
 			nanosleep(&t, NULL);
-		for (i = 0 ; i < ((int)(sizeof(s3drc) / sizeof(char **))) ; i++) {
+		for (i = 0; i < ((int)(sizeof(s3drc) / sizeof(char **))); i++) {
 			if ((*s3drc[i]) != NULL) {
 				s3dprintf(LOW, "[RC] launching %s", *s3drc[i]);
 				ret = system(*s3drc[i]);
@@ -102,7 +104,8 @@ int rc_init(void)
 		if (rc == NULL) {
 			errs("rc_init()", "You don't have an rc-script? Think about creating one (~/.s3drc), its handy :)");
 			errs("rc_init()", "Starting anyway ...");
-			while (1) sleep(1);
+			while (1)
+				sleep(1);
 		} else {
 			errs("rc_init()", "no usuable rc script found.");
 			errs("rc_init()", "Check your rc-script!");
@@ -114,8 +117,9 @@ int rc_init(void)
 		/* father just returns */
 	}
 #endif
-	return(0);
+	return 0;
 }
+
 /*  the mainloop, should be handling all signals */
 static void mainloop(void)
 {
@@ -127,16 +131,18 @@ static void mainloop(void)
 /*  things which should be done each time in main loop go here! this is */
 /*  just for the case we use a function for the mainloop like we do for glut... */
 
-static struct timespec t = {
-	0, 10*1000*1000
-}; /* 10 mili seconds */
 void one_time(void)
 {
+	struct timespec t = {
+		0, 10 * 1000 * 1000
+	};			/* 10 mili seconds */
+
 	nanosleep(&t, NULL);
 	user_main();
 	network_main();
 	graphics_main();
 }
+
 /*  this initalizes all components.  */
 int init(void)
 {
@@ -149,7 +155,7 @@ int init(void)
 #else
 	s3dprintf(VHIGH, "rc-files won't work without signals :(");
 #endif
-	if (!frame_mode) { /*  turn default frame_mode on */
+	if (!frame_mode) {	/*  turn default frame_mode on */
 #ifdef G_SDL
 		frame_mode = FRAME_SDL;
 #else
@@ -157,7 +163,7 @@ int init(void)
 	}
 	if (!frame_mode) {
 		errsf("init()", "no framework mode available");
-		return(-1);
+		return -1;
 	}
 	graphics_init();
 	network_init();
@@ -172,7 +178,7 @@ int init(void)
 	if (kidpid != 0)
 		kill(kidpid, SIGUSR1);
 #endif
-	return(0);
+	return 0;
 }
 
 /*  things to be cleaned up  */
@@ -184,7 +190,7 @@ void quit(void)
 		graphics_quit();
 		process_quit();
 #ifdef SIGS
-		if (kidpid != 0) { /* our kid is most probably still alive. kill it!! */
+		if (kidpid != 0) {	/* our kid is most probably still alive. kill it!! */
 			s3dprintf(HIGH, "kill all the kids!!");
 			kill(kidpid, SIGTERM);
 			kidpid = 0;
@@ -195,14 +201,15 @@ void quit(void)
 	s3dprintf(VHIGH, "byebye, s3d quitting ...");
 	exit(0);
 }
+
 /*  processing arguments from the commandline */
 static int process_args(int argc, char **argv)
 {
-	int      lopt_idx;
-	int      c;
+	int lopt_idx;
+	int c;
 	struct option long_options[] = {
-		{"multisample",  1, NULL, 'm'
-		}, {"rc",    1, NULL, 'r'}, {"help",   0, NULL, 'h'}, {"use-sdl",   0, NULL, 's'}, {"no-rc",   0, NULL, 'n'}, {NULL, 0, NULL, 0}
+		{
+		 "multisample", 1, NULL, 'm'}, {"rc", 1, NULL, 'r'}, {"help", 0, NULL, 'h'}, {"use-sdl", 0, NULL, 's'}, {"no-rc", 0, NULL, 'n'}, {NULL, 0, NULL, 0}
 	};
 	while (-1 != (c = getopt_long(argc, argv, "?hgsnr:m:", long_options, &lopt_idx))) {
 		switch (c) {
@@ -243,11 +250,12 @@ static int process_args(int argc, char **argv)
 #endif
 			s3dprintf(VHIGH, " --help, -?, -h: this helpful text");
 			errsf("process_args()", "exiting for users sake");
-			return(-1);
+			return -1;
 		}
 	}
-	return(0);
+	return 0;
 }
+
 /*  things to be done when program is started */
 int main(int argc, char **argv)
 {
@@ -255,5 +263,5 @@ int main(int argc, char **argv)
 	init();
 	mainloop();
 	quit();
-	return(0);
+	return 0;
 }
