@@ -1,7 +1,7 @@
 /*
  * mcp.c
  *
- * Copyright (C) 2004-2008 Simon Wunderlich <dotslash@packetmixer.de>
+ * Copyright (C) 2004-2011  Simon Wunderlich <dotslash@packetmixer.de>
  *
  * This file is part of s3d, a 3d network display server.
  * See http://s3d.berlios.de/ for more updates.
@@ -21,15 +21,14 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-
 #include "global.h"
-#include "proto.h"     /*  for S3D_P_OBJECT, to be integrated in proto.c */
+#include "proto.h"		/*  for S3D_P_OBJECT, to be integrated in proto.c */
 #ifdef WIN32
 #include <winsock2.h>
 #else
-#include <netinet/in.h>   /*  htonl() */
+#include <netinet/in.h>		/*  htonl() */
 #endif
-#include <string.h>    /*  strncpy() */
+#include <string.h>		/*  strncpy() */
 
 /*  this interacts with the actual mcp client */
 struct mcp_object {
@@ -39,7 +38,9 @@ struct mcp_object {
 	/*  char event; */
 	char name[S3D_NAME_MAX];
 };
+
 #define MCP_NEW_OBJECT 1
+
 /*  call when a new mcp connects */
 int mcp_init(void)
 {
@@ -49,7 +50,7 @@ int mcp_init(void)
 	i = p->n_obj;
 	while (i--) {
 		if (p->object[i] != NULL)
-			switch (p->object[i]->oflags&OF_TYPE) {
+			switch (p->object[i]->oflags & OF_TYPE) {
 			case OF_VIRTUAL:
 				mcp_rep_object(i);
 				break;
@@ -59,8 +60,9 @@ int mcp_init(void)
 			}
 	}
 	mcp_focus(-1);
-	return(0);
+	return 0;
 }
+
 /*  report the mcp about our object */
 int mcp_rep_object(int32_t mcp_oid)
 {
@@ -74,12 +76,12 @@ int mcp_rep_object(int32_t mcp_oid)
 	mo.r = p->object[mcp_oid]->r;
 
 	htonfb(&mo.trans_x, 4);
-	/*  mo.event=MCP_NEW_OBJECT; */
 	ap = get_proc_by_pid(p->object[mcp_oid]->virtual_pid);
 	strncpy(mo.name, ap->name, S3D_NAME_MAX);
-	prot_com_out(p, S3D_P_MCP_OBJECT, (uint8_t *)&mo, sizeof(struct mcp_object));
-	return(0);
+	prot_com_out(p, S3D_P_MCP_OBJECT, (uint8_t *) & mo, sizeof(struct mcp_object));
+	return 0;
 }
+
 /* tells the mcp that some program vanished ... */
 int mcp_del_object(int32_t mcp_oid)
 {
@@ -88,9 +90,10 @@ int mcp_del_object(int32_t mcp_oid)
 		s3dprintf(MED, "lost the focus of mcp-oid %d", mcp_oid);
 		mcp_focus(-1);
 	}
-	prot_com_out(get_proc_by_pid(MCP), S3D_P_MCP_DEL_OBJECT, (uint8_t *)&oid, 4);
-	return(0);
+	prot_com_out(get_proc_by_pid(MCP), S3D_P_MCP_DEL_OBJECT, (uint8_t *) & oid, 4);
+	return 0;
 }
+
 /* sets a new focus */
 int mcp_focus(int oid)
 {
@@ -100,18 +103,9 @@ int mcp_focus(int oid)
 	p = get_proc_by_pid(MCP);
 	s3dprintf(MED, "request to focus %d", oid);
 	if (OBJ_VALID(p, oid, o))
-		if (o->oflags&OF_VIRTUAL) {
+		if (o->oflags & OF_VIRTUAL) {
 			focus_oid = oid;
 			obj_pos_update(p, 0, 0);
 		}
-	return(0);
+	return 0;
 }
-
-/*  clean up functions after the mcp left */
-
-/* TODO: move things from object.c to this place!
-int mcp_quit(void)
-{
- return(0);
-}
-*/
