@@ -1,7 +1,7 @@
 /*
  * network.c
  *
- * Copyright (C) 2004-2008 Simon Wunderlich <dotslash@packetmixer.de>
+ * Copyright (C) 2004-2011  Simon Wunderlich <dotslash@packetmixer.de>
  *
  * This file is part of s3d, a 3d network display server.
  * See http://s3d.berlios.de/ for more updates.
@@ -21,18 +21,17 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-
 #include "global.h"
 #include <stdio.h>
-#include <stdlib.h>   /*  free() */
-#include <errno.h>   /*  errno() */
-#include <unistd.h>  /* close(), read(),write() */
-#include <signal.h>  /* SIGPIPE,SIG_ERR,SIGIO */
+#include <stdlib.h>		/*  free() */
+#include <errno.h>		/*  errno() */
+#include <unistd.h>		/* close(), read(),write() */
+#include <signal.h>		/* SIGPIPE,SIG_ERR,SIGIO */
 #ifdef G_SDL
-#include <SDL.h> /* SDL_SetTimer() */
+#include <SDL.h>		/* SDL_SetTimer() */
 #endif
 #ifdef SIGS
-#include <signal.h>  /*  sighandler_t SIG_PIPE */
+#include <signal.h>		/*  sighandler_t SIG_PIPE */
 #endif
 /*  here go all the network functions */
 /*  */
@@ -41,8 +40,8 @@
 
 /*  defines: */
 
-uint8_t ibuf[MAXPLEN]; /* input buffer for a packet */
-uint8_t obuf[MAXPLEN]; /* output buffer */
+uint8_t ibuf[MAXPLEN];		/* input buffer for a packet */
+uint8_t obuf[MAXPLEN];		/* output buffer */
 #ifdef SIGS
 static int sigio = 0;
 #endif
@@ -58,11 +57,12 @@ void sigio_handler(int S3DUNUSED(unused))
 	sigio = 1;
 }
 #endif
+
 /*  maybe change the errors to fatal errors ... */
 int network_init(void)
 {
 #ifdef SIGS
-	/* struct sigaction act;*/
+	/* struct sigaction act; */
 #endif
 #ifdef TCP
 	tcp_init();
@@ -73,20 +73,19 @@ int network_init(void)
 #ifdef SIGS
 	if (signal(SIGPIPE, sigpipe_handler) == SIG_ERR)
 		errn("network_init():signal()", errno);
-	/* act.sa_handler = (sig_t)sigio_handler;
-	 if ( sigaction(SIGIO, &act, 0) < 0 )
-	  errn("network_init():sigaction()",errno);*/
 	if (signal(SIGIO, sigio_handler) == SIG_ERR)
 		errn("s3d_init():signal()", errno);
 #endif
-	return(0);
+	return 0;
 }
-volatile int      turn;
+
+volatile int turn;
+
 int net_turn_off(int S3DUNUSED(interval))
 {
 	s3dprintf(VLOW, "Warning: High traffic on Network, interrupting read.");
 	turn = 0;
-	return(0);
+	return 0;
 }
 
 /*  this basicly polls for new connection */
@@ -96,13 +95,14 @@ int network_main(void)
 
 #ifdef TCP
 #ifdef SIGS
-	if (sigio == 1) { /*  as long as there is no locking/threadsafety, do like this ... */
+	if (sigio == 1) {	/*  as long as there is no locking/threadsafety, do like this ... */
 #endif
-		tcp_pollport(); /*  this polls for new processes */
+		tcp_pollport();	/*  this polls for new processes */
 #ifdef G_SDL
 		SDL_SetTimer(50, (SDL_TimerCallback) net_turn_off);
 #endif
-		while (turn && tcp_pollproc()) {}  /*  if there is new data, loop please. this is for testing now, and should be combined with timing later .. */
+		while (turn && tcp_pollproc()) {
+		}		/*  if there is new data, loop please. this is for testing now, and should be combined with timing later .. */
 #ifdef G_SDL
 		SDL_SetTimer(0, NULL);
 #endif
@@ -115,8 +115,9 @@ int network_main(void)
 #ifdef SHM
 	shm_main();
 #endif
-	return(0);
+	return 0;
 }
+
 int n_remove(struct t_process *p)
 {
 	switch (p->con_type) {
@@ -132,36 +133,37 @@ int n_remove(struct t_process *p)
 #endif
 	}
 	p->con_type = CON_NULL;
-	return(-1);
+	return -1;
 }
 
-int n_readn(struct t_process *p, uint8_t *str, int s)
+int n_readn(struct t_process *p, uint8_t * str, int s)
 {
 	switch (p->con_type) {
 #ifdef TCP
 	case CON_TCP:
-		return(tcp_readn(p->sockid, str, s));
+		return tcp_readn(p->sockid, str, s);
 #endif
 #ifdef SHM
 	case CON_SHM:
-		return(shm_readn((struct buf_t *)p->shmsock.data_ctos, str, s));
+		return shm_readn((struct buf_t *)p->shmsock.data_ctos, str, s);
 #endif
 	}
-	return(-1);
+	return -1;
 }
-int n_writen(struct t_process *p, uint8_t *str, int s)
+
+int n_writen(struct t_process *p, uint8_t * str, int s)
 {
 	switch (p->con_type) {
 #ifdef TCP
 	case CON_TCP:
-		return(tcp_writen(p->sockid, str, s));
+		return tcp_writen(p->sockid, str, s);
 #endif
 #ifdef SHM
 	case CON_SHM:
-		return(shm_writen((struct buf_t *)p->shmsock.data_stoc, str, s));
+		return shm_writen((struct buf_t *)p->shmsock.data_stoc, str, s);
 #endif
 	}
-	return(-1);
+	return -1;
 }
 
 int network_quit(void)
@@ -172,6 +174,5 @@ int network_quit(void)
 #ifdef SHM
 	shm_quit();
 #endif
-	return(0);
+	return 0;
 }
-
